#!/usr/bin/python
# -*- coding: utf8 -*-
#  LoremIpsumGenerator Plugin
#
#  Copyright (C) 2014 Marco Crippa
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import string
from gi.repository import GObject, Gtk, Gdk, Gedit

ui_str = """
<ui>
  <menubar name="MenuBar">
	<menu name="ToolsMenu" action="Tools">
	  <placeholder name="EditOps_2">
	    <menu name="LoremIpsumGenerator" action="LoremIpsumGenerator">
	      <menuitem name="1paragraph" action="1paragraph"/>
	      <menuitem name="2paragraph" action="2paragraph"/>
	      <menuitem name="3paragraph" action="3paragraph"/>
	      <menuitem name="4paragraph" action="4paragraph"/>
	      <menuitem name="5paragraph" action="5paragraph"/>
	    </menu>
	  </placeholder>
	</menu>
  </menubar>
</ui>
"""

class LoremIpsumGeneratorPlugin(GObject.Object, Gedit.WindowActivatable):
	__gtype_name__ = "LoremIpsumGenerator"
	window = GObject.property(type=Gedit.Window)

	arLorem = [
	"Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed fermentum tincidunt purus, et gravida nisi pellentesque quis. Ut ligula ante, ornare non quam in, tincidunt dapibus nibh. Fusce sit amet consequat arcu. Pellentesque tempus vehicula lorem, id volutpat nibh vehicula quis. Etiam vitae faucibus quam. Nullam eu sem massa. Etiam accumsan dui mi, non posuere odio tempus nec. Praesent id arcu ac eros ultrices sollicitudin at quis nisi. Quisque vel porttitor tellus.", 
	"Nam sed lectus et tortor tincidunt rutrum ut ac lorem. Sed et nunc at metus bibendum facilisis vitae sit amet enim. Sed hendrerit placerat urna non bibendum. Sed fermentum congue odio, eget tempus felis sodales a. Proin volutpat placerat leo quis rhoncus. Phasellus semper sapien justo, vel blandit ante tincidunt et. Sed convallis ut erat in posuere.",
	"Vestibulum gravida sollicitudin est, pulvinar luctus odio aliquam sed. Nulla imperdiet mollis felis sed blandit. Sed sodales lacus ac laoreet iaculis. Aliquam vel eros ac mauris faucibus sodales convallis ac dui. Quisque id faucibus enim. Aliquam semper euismod dignissim. Etiam mattis ligula vel iaculis volutpat.",
	"In hac habitasse platea dictumst. Sed sodales erat mi, vel porta orci gravida tincidunt. Nam at nisi sed augue vestibulum ornare. Proin at congue sapien. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Nam pellentesque purus ut odio ultricies blandit. Nulla sit amet nulla eu urna aliquet pulvinar. Donec adipiscing placerat blandit. Vestibulum fringilla a ipsum eget varius.",
	"Fusce rutrum commodo nulla, vel mattis ante ultrices ac. Nulla in blandit elit, eget pulvinar augue. Aliquam gravida sit amet dui ut dignissim. Nulla a consectetur lectus. Maecenas ac justo sapien. Nam quis ultricies turpis. Cras vel tempus felis. Aliquam at lectus eget magna auctor tincidunt. Sed ultricies massa aliquet lacus semper auctor. Duis laoreet sapien velit, a molestie lectus pellentesque id. Nunc at laoreet nisl. Mauris vel ullamcorper felis, eget dapibus est. Donec bibendum odio sed magna tincidunt, et porttitor libero tincidunt. In tempor ullamcorper ante ut suscipit."
	]

	def __init__(self):
		GObject.Object.__init__(self)

	def do_activate(self):
		actions = [
		  ('LoremIpsumGenerator',None, 'Lorem Ipsum Generator'),
		  ('1paragraph',None, 'Add 1 paragraph...','<Control><Alt>1','Add 1 paragraph',self.paragraph1),
		  ('2paragraph',None, 'Add 2 paragraphs...','<Control><Alt>2','Add 2 paragraph',self.paragraph2),
		  ('3paragraph',None, 'Add 3 paragraphs...','<Control><Alt>3','Add 3 paragraph',self.paragraph3),
		  ('4paragraph',None, 'Add 4 paragraphs...','<Control><Alt>4','Add 4 paragraph',self.paragraph4),
		  ('5paragraph',None, 'Add 5 paragraphs...','<Control><Alt>5','Add 5 paragraph',self.paragraph5)
		  ]

		self._actions = Gtk.ActionGroup("GeditLoremIpsumGeneratorPluginActions")
		self._actions.add_actions(actions)

		manager = self.window.get_ui_manager()
		manager.insert_action_group(self._actions)

		self._ui_merge_id = manager.add_ui_from_string(ui_str)
		manager.ensure_update()

	def do_deactivate(self):
		manager = self.window.get_ui_manager()
		manager.remove_ui(self._ui_merge_id)
		manager.remove_action_group(self._actions)
		manager.ensure_update()

	def do_update_state(self):
		view = self.window.get_active_view()
		self._actions.set_sensitive(bool(view and view.get_editable()))

	def paragraph1(self, action):
		self.insertText(1)

	def paragraph2(self, action):
		self.insertText(2)

	def paragraph3(self, action):
		self.insertText(3)

	def paragraph4(self, action):
		self.insertText(4)

	def paragraph5(self, action):
		self.insertText(5)

	def insertText(self, nPar):
		text=""
		for count in range(0,nPar):
			text+=self.arLorem[count]
			if count != (nPar-1):
				text+="\n\n"

		doc = self.window.get_active_document()
		doc.begin_user_action()
		doc.insert_at_cursor(text)
		doc.end_user_action()
		
